@@ -1471,12 +1471,12 @@ int main(int argc, char * argv[])
           pluginType_t * plugins;
           pluginType_t * plugin;
           char localPluginDir[200];
-          struct stat details;
           int pluginIdx = 0;
           char * config_fname;
 
           snprintf(localPluginDir, sizeof(localPluginDir), browsers[i].localPluginDir, home);
-          if(stat(localPluginDir, &details) != 0)
+
+          if( (mkdir(localPluginDir, S_IRWXU) != 0) && (errno != EEXIST))
           {
                continue;
           }
