@@ -722,23 +722,23 @@ static void read_config(FILE * f)
      command_t * prev_cmd = NULL;
      mimetype_t * prev_type = NULL;
 
-     char buffer[LARGE_BUFFER_SIZE];
+     char lineBuf[512];
      int lineNum;
 
      D("read_config\n");
 
      lineNum = 0;
-     while (fgets(buffer, sizeof(buffer), f))
+     while (fgets(lineBuf, sizeof(lineBuf), f))
      {
           lineNum++;
-          if(!chkCfgLine(buffer))
+          if(!chkCfgLine(lineBuf))
           {
                continue;
           }
 
-	  D("%5i::|%s|\n", lineNum, buffer);
+	  D("%5i::|%s|\n", lineNum, lineBuf);
 
-          if(isCfgMimeType(buffer))
+          if(isCfgMimeType(lineBuf))
 	  {
 	       /* Mime type */
                mimetype_t * type = NULL;
@@ -773,7 +773,7 @@ static void read_config(FILE * f)
                     num_handlers++;
 	       }
 
-               type = parseCfgMimeType(buffer);
+               type = parseCfgMimeType(lineBuf);
                if(!type)
                {
                     return; /* run out of memory! */
@@ -793,7 +793,7 @@ static void read_config(FILE * f)
 	  }
 	  else
 	  {
-               command_t * cmd = parseCfgCmdLine(buffer);
+               command_t * cmd = parseCfgCmdLine(lineBuf);
                if(!cmd)
                {
                     return; /* run out of memory! */
@@ -828,7 +828,7 @@ static void read_config(FILE * f)
  *
  * @param[in] magic references for this particular plugin type
  *
- * @return none
+ * @return false if failed, true otherwise
  */
 static bool do_read_config(const char * magic)
 {
@@ -876,9 +876,9 @@ static bool do_read_config(const char * magic)
  * @param[in] name The name to check
  * @param[in] isURL Is the name a URL or filename?
  *
- * @return 1(true) if OK, 0(false) if not
+ * @return true if OK, false if not
  */
-static int safeName(const char* name, int isURL)
+static bool safeName(const char* name, int isURL)
 {
      int i = 0;
      const int len = strlen(name);
@@ -886,7 +886,7 @@ static int safeName(const char* name, int isURL)
      if ((name[0] == '/') && (isURL))
      {
           D("safeName() - reject URL '%s' as starts with '/'\n", name);
-	  return 0;
+	  return false;
      }
 
      for (i = 0; i < len; i++)
@@ -895,10 +895,10 @@ static int safeName(const char* name, int isURL)
 	  {
                D("safeName() - reject '%s' as contains either ';' or '`'\n", name);
 	       /* Somebody's trying to do something naughty. */
-	       return 0;
+	       return false;
 	  }
      }
-     return 1;
+     return true;
 }
 
 /**
@@ -910,6 +910,7 @@ static int safeName(const char* name, int isURL)
  * @param[in] THIS Pointer to the instance data
  * @param[in] headers The HTTP headers to parse
  * @param[out] fileName The file Name extracted from the headers
+ * @param[in] maxFileNameLen The max length of fileName
  *
  * @return None
  */
@@ -958,6 +959,7 @@ static void parseHeaders(data_t * const THIS, const char * headers, char * fileN
  *
  * @param[in] THIS Pointer to the instance data
  * @param[out] fileName The file Name extracted from the URL
+ * @param[in] maxFileNameLen The max length of fileName
  *
  * @return None
  */
@@ -2054,6 +2056,8 @@ static void new_child(NPP instance, const char* fname, int isURL)
 /**
  * Whilst creating a pdf watch out for characters that may
  * cause issues...
+ *
+ * @param[in,out] string the string to be escaped
  */
 static void escapeBadChars(char * string)
 {
@@ -2074,6 +2078,8 @@ static void escapeBadChars(char * string)
  * Creates a temporary file name based on the fileName provided. Checks that
  * the filename created does not include any dangereous or awkward characters.
  *
+ * @param[in] fileName Pointer to url string
+ *
  * @return file descriptor
  */
 static int guessTmpFile(const char * fileName, int soFar,
@@ -2197,7 +2203,7 @@ static int createTmpFile(const char * fileName,
 NPError NPP_NewStream(NPP instance, NPMIMEType type, NPStream *stream,
 		      NPBool seekable, uint16_t *stype)
 {
-     char fileName[SMALL_BUFFER_SIZE];
+     char fileName[512];
      char * savedMimetype = NULL;
      data_t * THIS;
      char refind_command = 0;
@@ -2292,7 +2298,7 @@ NPError NPP_NewStream(NPP instance, NPMIMEType type, NPStream *stream,
 
      if( (THIS->command->flags & H_STREAM) == 0)
      {
-          char tmpfile[LARGE_BUFFER_SIZE];
+          char tmpfile[512];
 
           THIS->tmpFileFd = createTmpFile(fileName, tmpfile, sizeof(tmpfile));
 
